==> CSBS-VBS-Upgrade-Plugin-8.3.0.zip: CSBS/scripts/cipher_change/karborproxy/sub_job_pre_check_os.py <==
import utils.common.log as logger
from utils.common.check_result import CheckResult
from utils.common.exception import HCCIException
from utils.common.message import Message

from plugins.CSBS.common.ssh_client import SshClient
from plugins.CSBS.common.step_base import UpgradeBaseSubJob
from plugins.CSBS.common.upgrade.karborproxy import KarborProxyOperation
from plugins.CSBS.common.upgrade.params import ParamsTools

logger.init("KarborProxy")


class ProxyPreCheckOS(UpgradeBaseSubJob):
    def __init__(self, project_id, pod_id, regionid_list):
        super(ProxyPreCheckOS, self).__init__(project_id, pod_id, regionid_list)
        self.karborproxy = KarborProxyOperation(project_id)
        self.param_tool = ParamsTools(project_id)
        self.ssh_client = SshClient()

    def execute(self, project_id, pod_id, regionid_list=None):
        """Plug-in internal interface.

        Perform installation & configuration.
        """
        proxy_cpu_arch = self.karborproxy.get_karborproxy_cpu_arch()
        # x86不支持补丁升级和密码算法切换
        if self.param_tool.is_x86_scene or proxy_cpu_arch.lower() != "arm":
            logger.error("The x86 system architecture does not support switch cipher.")
            return Message(500, HCCIException(645036))

        try:
            result = self.karborproxy.check_karborproxy_os_version()
        except Exception as e:
            logger.error(f"Execute error:{e}.")
            return Message(500, HCCIException(645044, str(e)))
        if not result:
            return Message(500, HCCIException(645036))
        logger.info("Succeed to check the KarborProxy")
        return Message(200, check_results=[CheckResult(status="success")])

==> CSBS-VBS-Upgrade-Plugin-8.3.1.zip: CSBS/scripts/cipher_change/karborproxy/sub_job_pre_check_os.py <==
import utils.common.log as logger
from utils.common.check_result import CheckResult
from utils.common.exception import HCCIException
from utils.common.message import Message

from plugins.CSBS.common.ssh_client import SshClient
from plugins.CSBS.common.step_base import UpgradeBaseSubJob
from plugins.CSBS.common.upgrade.karborproxy import KarborProxyOperation
from plugins.CSBS.common.upgrade.params import ParamsTools

logger.init("KarborProxy")


class ProxyPreCheckOS(UpgradeBaseSubJob):
    def __init__(self, project_id, pod_id, regionid_list):
        super(ProxyPreCheckOS, self).__init__(project_id, pod_id, regionid_list)
        self.karborproxy = KarborProxyOperation(project_id)
        self.param_tool = ParamsTools(project_id)
        self.ssh_client = SshClient()

    def execute(self, project_id, pod_id, regionid_list=None):
        """Plug-in internal interface.

        Perform installation & configuration.
        """
        proxy_cpu_arch = self.karborproxy.get_karborproxy_cpu_arch()
        # x86不支持补丁升级和密码算法切换
        if self.param_tool.is_x86_scene or proxy_cpu_arch.lower() != "arm":
            logger.error("The x86 system architecture does not support switch cipher.")
            return Message(500, HCCIException(645036))

        try:
            result = self.karborproxy.check_karborproxy_os_version()
        except Exception as err:
            logger.error(f"Execute error:{err}.")
            return Message(500, HCCIException(645044, str(err)))
        if not result:
            return Message(500, HCCIException(645036))
        logger.info("Succeed to check the KarborProxy")
        return Message(200, check_results=[CheckResult(status="success")])
